@@ -1,4 +1,4 @@
-from .webapi import *
+from .webapi import EnumParam as EnumParam, APIObj as APIObj, WebAPI as WebAPI
 from .oauth2 import OAuth2 as OAuth2, OAuth2User as OAuth2User
 from .oauth1 import OAuth1 as OAuth1, OAuth1User as OAuth1User
 from .auth import APIKey as APIKey
