@@ -10,9 +10,7 @@ class TestAPI(WebAPI):
         await super()._async_init()
         self.attr_initialized_after_await = 1
 
-
-
-async def test_error_unintialized():
+async def test_error_uninitialized():
 
     api_unawaited = TestAPI()
 
